@@ -112,12 +112,12 @@ class Tier(object):
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
-        if by == 0:
+        if by == _by.TIME:
             for point in self.__points:
                 if point.time == by_target:
                     return point
 
-        elif by == 1:
+        elif by == _by.INDEX:
             try:
                 point = self.__points[by_target-1]
 
@@ -125,13 +125,37 @@ class Tier(object):
             except IndexError:
                 pass
 
-        elif by == 2:
+        elif by == _by.POINT:
             for point in self.__points:
                 if point == by_target:
                     return point
 
         if not parameters['points.ignore_missing_point']:
             raise Exception('Point not found.')
+    
+    def get_closest_point(self, by_target, by, point_type=None):
+        
+        if by_target==_by.TIME:
+            points = self.__points.copy()
+            
+            if point_type==None:
+                pass
+            elif point_type=='larger':
+                points = [point for point in points if point.time>=time]
+            elif point_type=='smaller':
+                points = [point for point in points if point.time<=time]
+            else:
+                raise Exception(
+                    '`point_type` can only by one of {`larger`, `smaller`, None}.'
+                )
+            
+            points.sort(key=lambda point: (point.time - time))
+            
+            return points[0]
+        
+        else:
+            return self.get_point(by_target, by)
+        
 
     def get_points(self, by_target, by):
         """Get a list of Point objects with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
@@ -199,7 +223,7 @@ class Tier(object):
         self._reindex()
         self._indexed = True
 
-    def interpolate_points(self, by_target, by, step=.01):
+    def interpolate_points(self, by_target, by, step=.01, strict=True):
         """Interpolate values between two Point objects (array-like), with given step (by default 0.01s). See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
 
         if by not in _by.by_methods:
@@ -214,8 +238,13 @@ class Tier(object):
         original_ignore_missing_point_parameter = parameters['points.ignore_missing_point']
         parameters['points.ignore_missing_point'] = False
         
-        points = self.get_points(by_target, by)
-        if points[0].time <= points[1]:
+        if by == _by.TIME and not strict:
+            points = self.get_closest_point(min(by_target), by, point_type='smaller'), self.get_closest_point(max(by_target), by, point_type='larger')
+        
+        else:
+            points = self.get_points(by_target, by)
+        
+        if points[0].time <= points[1].time:
             point1, point2 = points[0], points[1]
         else:
             point1, point2 = points[1], points[0]
